@@ -1,19 +1,22 @@
 # SPDX-FileCopyrightText: 2025-present pedro <pedro@noxus.ai>
 #
 # SPDX-License-Identifier: MIT
-from no_llm.config.enums import ModelCapability
-from no_llm.config.metadata import (
+from no_llm.models.config.enums import ModelCapability
+from no_llm.models.config.metadata import (
     CharacterPrices,
     ModelMetadata,
     ModelPricing,
     PrivacyLevel,
     TokenPrices,
 )
-from no_llm.config.model import ModelConfiguration
-from no_llm.config.parameters import ModelParameters, ValidationMode
-from no_llm.registry import ModelRegistry
+from no_llm.models.config.model import ModelConfiguration
+from no_llm.models.config.parameters import ModelParameters, ValidationMode
+from no_llm.models.registry import ModelRegistry
+from no_llm.providers.registry import ProviderRegistry
+from no_llm.registry import Registry
 
 __all__ = [
+    "Registry",
     "ModelRegistry",
     "ModelCapability",
     "ModelMetadata",
@@ -24,4 +27,5 @@ __all__ = [
     "ModelConfiguration",
     "ValidationMode",
     "ModelParameters",
+    "ProviderRegistry",
 ]
